pub struct Tui<B: Backend> {
pub events: EventHandler,
/* private fields */
}Expand description
Representation of a terminal user interface.
It is responsible for setting up the terminal, initializing the interface and handling the draw events.
Fields
events: EventHandlerTerminal event handler.
Implementations
Sourceimpl<B: Backend> Tui<B>
impl<B: Backend> Tui<B>
Sourcepub fn new(terminal: Terminal<B>, events: EventHandler) -> Self
pub fn new(terminal: Terminal<B>, events: EventHandler) -> Self
Constructs a new instance of Tui.
Sourcepub fn init(&mut self) -> AppResult<()>
pub fn init(&mut self) -> AppResult<()>
Initializes the terminal interface.
It enables the raw mode and sets terminal properties.